@@ -43,9 +43,18 @@ def log2p_dict(scale):
 
 """
 Standard dictionary stored for ease of access
+Now available in 3K and 10K format for standard scale
 """
 standard_scale_1p_2p= [0, 1, 3, 10, 30, 100, 300, 1000, 3000]
 standard_scale = [0,100,300,1000,3000]
+
 dictionary_stand = norm_dict(standard_scale)
 dictionary_stand_1p = log1p_dict(standard_scale_1p_2p)
-dictionary_stand_2p = log2p_dict(standard_scale_1p_2p)
\ No newline at end of file
+dictionary_stand_2p = log2p_dict(standard_scale_1p_2p)
+
+standard_scale_1p_2p_10k= [0, 1, 3, 10, 30, 100, 300, 1000, 3000, 10000]
+standard_scale_10k = [0,100,300,1000,3000,10000]
+
+dictionary_stand_10k = norm_dict(standard_scale_10k)
+dictionary_stand_1p_10k = log1p_dict(standard_scale_1p_2p_10k)
+dictionary_stand_2p_10k = log2p_dict(standard_scale_1p_2p_10k)
\ No newline at end of file
