@@ -7,6 +7,7 @@ from ingester3.ViewsMonth import ViewsMonth
 from ingester3.Country import Country
 import pycountry
 from datetime import date
+import os
 
 
 def vid2date(month_id):
@@ -90,3 +91,32 @@ def name_date2cid(country, date_string):
             output= 'check_spelling'
     return output
 
+def give_me_top10_country_id(df, month_value, var_name):
+    """the dataframe must contain month_id and country_id columns with those names"""
+    df = df.reset_index()
+    df = df.set_index(['country_id', 'month_id'])
+    temp = df.iloc[df.index.get_level_values('month_id') == month_value]
+    temp2 = temp.nlargest(10, str(var_name))
+    output = list(temp2.groupby('country_id').groups.keys())
+    return output
+
+def give_me_top10_names(df, month_value, var_name):
+    """the dataframe must contain month_id and country_id columns with those names"""
+    df = df.reset_index()
+    df = df.set_index(['country_id', 'month_id'])
+    temp = df.iloc[df.index.get_level_values('month_id') == month_value]
+    temp2 = temp.nlargest(10, str(var_name))
+
+    list_1 = list()
+    for i in list(temp2.groupby('country_id').groups.keys()):
+        list_1.append(Country(i).name)
+    output = list_1
+    return output
+
+def make_a_folder(folderpath):
+    if not os.path.exists(folderpath):
+        os.mkdir(folderpath)
+        print('Directory', folderpath, "created")
+    else:
+        print('Directory', folderpath, 'already exists')
+
